==> qlevar_router-1.5.11.tar.gz: example/lib/pages/welcome/welcome_view.dart <==
import 'package:flutter/material.dart';
import 'package:qlevar_router/qlevar_router.dart';

import '../../routes/dashboard_routes.dart';
import '../../routes/mobile_routes.dart';
import '../../routes/store_routes.dart';
import 'debug_tools.dart';
import 'node_widget.dart';

class WelcomeView extends StatelessWidget {
  const WelcomeView({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Welcome to Qlevar Router'),
        centerTitle: true,
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: [
            NodeWidget(
              name: 'Store',
              // Navigate with route name
              onPressed: () => QR.toName(StoreRoutes.store),
            ),
            NodeWidget(
              name: 'Dashboard',
              onPressed: () => QR.toName(DashboardRoutes.dashboard),
            ),
            NodeWidget(
              name: 'Mobile',
              onPressed: () => QR.toName(MobileRoutes.mobile),
            ),
            NodeWidget(
              name: 'Middleware',
              // Navigate with route path
              onPressed: () => QR.to('/parent'),
            ),
            NodeWidget(
              name: 'Declarative',
              onPressed: () => QR.to('/declarative'),
            ),
            NodeWidget(
              name: 'Editable Routes',
              onPressed: () => QR.to('/editable-routes'),
            ),
          ],
        ),
      ),
      floatingActionButton: DebugTools(),
    );
  }
}

==> qlevar_router-1.9.1.tar.gz: example/lib/pages/welcome/welcome_view.dart <==
import 'package:flutter/material.dart';
import 'package:qlevar_router/qlevar_router.dart';

import '../../routes/dashboard_routes.dart';
import '../../routes/mobile_routes.dart';
import '../../routes/store_routes.dart';
import 'debug_tools.dart';
import 'node_widget.dart';

class WelcomeView extends StatelessWidget {
  const WelcomeView({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Welcome to Qlevar Router'),
        centerTitle: true,
      ),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly,
          children: [
            NodeWidget(
              name: 'Store',
              // Navigate with route name
              onPressed: () => QR.toName(StoreRoutes.store),
            ),
            NodeWidget(
              name: 'Dashboard',
              onPressed: () => QR.toName(DashboardRoutes.dashboard),
            ),
            NodeWidget(
              name: 'Mobile',
              onPressed: () => QR.toName(MobileRoutes.mobile),
            ),
            NodeWidget(
              name: 'Middleware',
              // Navigate with route path
              onPressed: () => QR.to('/parent'),
            ),
            NodeWidget(
              name: 'Declarative',
              onPressed: () => QR.to('/declarative'),
            ),
            NodeWidget(
              name: 'Editable Routes',
              onPressed: () => QR.to('/editable-routes'),
            ),
          ],
        ),
      ),
      floatingActionButton: const DebugTools(),
    );
  }
}
